@@ -10,10 +10,12 @@ import six
 import six.moves.urllib.parse as urlparse
 
 from .. import MEDIA_TYPE_STIX_V20, MEDIA_TYPE_TAXII_V20
-from ..common import _filter_kwargs_to_query_params, _grab_total_items, _to_json, _TAXIIEndpoint
+from ..common import (
+    _filter_kwargs_to_query_params, _grab_total_items, _TAXIIEndpoint,
+    _to_json
+)
 from ..exceptions import AccessError, ValidationError
 
-
 # Module-level logger
 log = logging.getLogger(__name__)
 log.propagate = False
@@ -735,6 +737,3 @@ class Server(_TAXIIEndpoint):
         response = self.__raw = self._conn.get(self.url)
         self._populate_fields(**response)
         self._loaded = True
-
-
-__all__ = ["ApiRoot", "Collection", "Server", "Status", "as_pages"]
